zstd library

Classes

RawZstdFilter
The RawZstdFilter class provides a low-level interface to zstd.
ZstdCodec
The ZstdCodec encodes raw bytes to zstd compressed bytes and decodes zstd compressed bytes to raw bytes.
ZstdDecoder
The ZstdDecoder is used by ZstdCodec and GZipCodec to decompress data.
ZstdEncoder
The ZstdEncoder encoder is used by ZstdCodec and GZipCodec to compress data.
ZstdOption
Exposes zstd options for input parameters.

Constants

zstd → const ZstdCodec
An instance of the default implementation of the ZstdCodec.